@@ -280,7 +280,7 @@ int SuProcess::ConverseSU(const char *password)
 
                 // Match "Password: " with the regex ^[^:]+:[\w]*$.
                 const uint len = line.length();
-                for (i=0,j=0,colon=0; i<len; i++)
+                for (i=0,j=0,colon=0; i<len; ++i)
                 {
                     if (line[i] == ':')
                     {
@@ -294,21 +294,11 @@ int SuProcess::ConverseSU(const char *password)
                 {
                     if (password == 0L)
                         return killme;
-                    if (!checkPid(m_Pid))
-                    {
-                        kError(kdesuDebugArea()) << "su has exited while waiting for pwd." << endl;
+                    if (WaitSlave())
                         return error;
-                    }
-                    if ((WaitSlave() == 0) && checkPid(m_Pid))
-                    {
-                        write(fd(), password, strlen(password));
-                        write(fd(), "\n", 1);
-                        state=CheckStar;
-                    }
-                    else
-                    {
-                        return error;
-                    }
+                    write(fd(), password, strlen(password));
+                    write(fd(), "\n", 1);
+                    state = CheckStar;
                 }
                 break;
             }
@@ -322,7 +312,7 @@ int SuProcess::ConverseSU(const char *password)
                     break;
                 }
                 const uint len = line.length();
-                for (i=0; i< len; i++)
+                for (i=0; i< len; ++i)
                     {
                 if (s[i] != '*')
                     return error;
