@@ -82,7 +82,7 @@ struct PalInfo
 
 PalInfo palInfo[] =
 {
-    {QPalette::Foreground, 0xff000000},
+    {QPalette::WindowText, 0xff000000},
     {QPalette::Button, 0xffc0c0c0},
     {QPalette::Light, 0xffffffff},
     {QPalette::Midlight, 0xffdfdfdf},
@@ -92,7 +92,7 @@ PalInfo palInfo[] =
     {QPalette::BrightText, 0xffffffff},
     {QPalette::ButtonText, 0xff000000},
     {QPalette::Base, 0xffffffff},
-    {QPalette::Background, 0xffc0c0c0},
+    {QPalette::Window, 0xffc0c0c0},
     {QPalette::Shadow, 0xff000000},
     {QPalette::Highlight, 0xff000080},
     {QPalette::HighlightedText, 0xffffffff},
@@ -103,7 +103,7 @@ PalInfo palInfo[] =
 
 PalInfo disPalInfo[] =
 {
-    {QPalette::Foreground, 0xff808080},
+    {QPalette::WindowText, 0xff808080},
     {QPalette::Button, 0xffc0c0c0},
     {QPalette::Light, 0xffffffff},
     {QPalette::Midlight, 0xffdfdfdf},
@@ -113,7 +113,7 @@ PalInfo disPalInfo[] =
     {QPalette::BrightText, 0xffffffff},
     {QPalette::ButtonText, 0xff808080},
     {QPalette::Base, 0xffc0c0c0},
-    {QPalette::Background, 0xffc0c0c0},
+    {QPalette::Window, 0xffc0c0c0},
     {QPalette::Shadow, 0xff000000},
     {QPalette::Highlight, 0xff000080},
     {QPalette::HighlightedText, 0xffffffff},
@@ -297,11 +297,11 @@ void PartMonitor::waitForCompletion()
 
         enterLoop();
 
-        //connect(m_timeout_timer, SIGNAL(timeout()), this, SLOT( timeout() ) );
+        //connect(m_timeout_timer, SIGNAL(timeout()), this, SLOT(timeout()) );
         //m_timeout_timer->stop();
 	//m_timeout_timer->start( visual ? 100 : 2, true );
     }
-    QTimer::singleShot( 0, this, SLOT( finishTimers() ) );
+    QTimer::singleShot( 0, this, SLOT(finishTimers()) );
     enterLoop();
 }
 
@@ -332,7 +332,7 @@ void PartMonitor::finishTimers()
     --m_timer_waits;
     if ( m_timer_waits && ((w && w->winq->hasTimers()) || m_part->inProgress())) {
         // wait a bit
-        QTimer::singleShot( 10, this, SLOT(finishTimers() ) );
+        QTimer::singleShot( 10, this, SLOT(finishTimers()) );
         return;
     }
     exitLoop();
@@ -342,7 +342,7 @@ void PartMonitor::partCompleted()
 {
     m_completed = true;
     m_timeout_timer->stop();
-    connect(m_timeout_timer, SIGNAL(timeout()),this, SLOT( timeout() ) );
+    connect(m_timeout_timer, SIGNAL(timeout()),this, SLOT(timeout()) );
 	m_timeout_timer->setSingleShot(true);
 	m_timeout_timer->start(visual ? 100 : 2);
     disconnect(m_part,SIGNAL(completed()),this,SLOT(partCompleted()));
@@ -802,10 +802,10 @@ int main(int argc, char *argv[])
                                                         args->isSet("genoutput"),
                                                         !args->isSet( "html" ),
                                                         !args->isSet( "js" ));
-    QObject::connect(part->browserExtension(), SIGNAL(openUrlRequest(const KUrl&, const KParts::OpenUrlArguments&, const KParts::BrowserArguments&)),
-		     regressionTest, SLOT(slotOpenURL(const KUrl&, const KParts::OpenUrlArguments&, const KParts::BrowserArguments&)));
-    QObject::connect(part->browserExtension(), SIGNAL(resizeTopLevelWidget( int, int )),
-		     regressionTest, SLOT(resizeTopLevelWidget( int, int )));
+    QObject::connect(part->browserExtension(), SIGNAL(openUrlRequest(KUrl,KParts::OpenUrlArguments,KParts::BrowserArguments)),
+		     regressionTest, SLOT(slotOpenURL(KUrl,KParts::OpenUrlArguments,KParts::BrowserArguments)));
+    QObject::connect(part->browserExtension(), SIGNAL(resizeTopLevelWidget(int,int)),
+		     regressionTest, SLOT(resizeTopLevelWidget(int,int)));
 
     bool result = false;
     QStringList tests = args->getOptionList("test");
@@ -1530,7 +1530,7 @@ void RegressionTest::testStaticFile(const QString & filename)
             return;
         }
 
-        KJS::Completion comp2 = m_part->jScriptInterpreter()->evaluate(filename, 0, "setUpPage(); " + functionname + "();" );
+        KJS::Completion comp2 = m_part->jScriptInterpreter()->evaluate(filename, 0, QString("setUpPage(); " + functionname + "();") );
         bool success = ( comp2.complType() == ReturnValue || comp2.complType() == Normal );
         QString description = "DOMTS";
         if ( comp2.complType() == Throw ) {
